@@ -23,7 +23,7 @@ trait WithDorisEngine extends WithJdbcEngine with WithDorisContainer {
 
   override def withKyuubiConf: Map[String, String] = Map(
     ENGINE_SHARE_LEVEL.key -> "SERVER",
-    ENGINE_JDBC_CONNECTION_URL.key -> s"jdbc:mysql://$feUrl",
+    ENGINE_JDBC_CONNECTION_URL.key -> feJdbcUrl,
     ENGINE_JDBC_CONNECTION_USER.key -> "root",
     ENGINE_JDBC_CONNECTION_PASSWORD.key -> "",
     ENGINE_TYPE.key -> "jdbc",
